@@ -3,7 +3,6 @@ from injecta.config.YamlConfigReader import YamlConfigReader
 from injecta.container.ContainerInterface import ContainerInterface
 from injecta.package.pathResolver import resolvePath
 from typing import List
-from pyfony.PyfonyBundle import PyfonyBundle
 from pyfony.kernel.BaseKernel import BaseKernel
 from pyfonybundles.Bundle import Bundle
 from datalakebundle.DataLakeBundle import DataLakeBundle
@@ -13,7 +12,6 @@ def initContainer(appEnv) -> ContainerInterface:
 
         def _registerBundles(self) -> List[Bundle]:
             return [
-                PyfonyBundle(),
                 ConsoleBundle(),
                 DataLakeBundle()
             ]
